@@ -13,7 +13,7 @@ pub static ADAPTOR: RoCell<Adapter> = RoCell::new();
 static SHOWN: SyncCell<Option<ratatui::layout::Rect>> = SyncCell::new(None);
 
 // Tmux support
-pub static TMUX: RoCell<u8> = RoCell::new();
+pub static TMUX: RoCell<bool> = RoCell::new();
 static ESCAPE: RoCell<&'static str> = RoCell::new();
 static START: RoCell<&'static str> = RoCell::new();
 static CLOSE: RoCell<&'static str> = RoCell::new();
@@ -39,9 +39,9 @@ pub fn init() -> anyhow::Result<()> {
 pub fn init_default() {
 	// Tmux support
 	TMUX.init(Mux::tmux_passthrough());
-	ESCAPE.init(if *TMUX == 2 { "\x1b\x1b" } else { "\x1b" });
-	START.init(if *TMUX == 2 { "\x1bPtmux;\x1b\x1b" } else { "\x1b" });
-	CLOSE.init(if *TMUX == 2 { "\x1b\\" } else { "" });
+	ESCAPE.init(if *TMUX { "\x1b\x1b" } else { "\x1b" });
+	START.init(if *TMUX { "\x1bPtmux;\x1b\x1b" } else { "\x1b" });
+	CLOSE.init(if *TMUX { "\x1b\\" } else { "" });
 
 	// WSL support
 	WSL.init(in_wsl());
