@@ -4,12 +4,20 @@ mod args;
 use std::{env, error::Error};
 
 use clap::CommandFactory;
-use clap_complete::{generate_to, Shell};
-use vergen_gitcl::{BuildBuilder, Emitter, GitclBuilder};
+use clap_complete::{Shell, generate_to};
+use vergen_gitcl::{BuildBuilder, Emitter, GitclBuilder, RustcBuilder};
 
 fn main() -> Result<(), Box<dyn Error>> {
 	Emitter::default()
 		.add_instructions(&BuildBuilder::default().build_date(true).build()?)?
+		.add_instructions(
+			&RustcBuilder::default()
+				.commit_date(true)
+				.commit_hash(true)
+				.host_triple(true)
+				.semver(true)
+				.build()?,
+		)?
 		.add_instructions(&GitclBuilder::default().commit_date(true).sha(true).build()?)?
 		.emit()?;
 
@@ -22,11 +30,10 @@ fn main() -> Result<(), Box<dyn Error>> {
 	let out = "completions";
 
 	std::fs::create_dir_all(out)?;
-	generate_to(Shell::Bash, cmd, bin, out)?;
-	generate_to(Shell::Fish, cmd, bin, out)?;
-	generate_to(Shell::Zsh, cmd, bin, out)?;
-	generate_to(Shell::Elvish, cmd, bin, out)?;
-	generate_to(Shell::PowerShell, cmd, bin, out)?;
+	for sh in [Shell::Bash, Shell::Fish, Shell::Zsh, Shell::Elvish, Shell::PowerShell] {
+		generate_to(sh, cmd, bin, out)?;
+	}
+
 	generate_to(clap_complete_nushell::Nushell, cmd, bin, out)?;
 	generate_to(clap_complete_fig::Fig, cmd, bin, out)?;
 
