@@ -2,20 +2,40 @@ yazi_macro::mod_pub!(package);
 
 yazi_macro::mod_flat!(args);
 
+use std::process::ExitCode;
+
 use clap::Parser;
+use yazi_macro::{errln, outln};
 
 #[tokio::main]
-async fn main() -> anyhow::Result<()> {
+async fn main() -> ExitCode {
+	match run().await {
+		Ok(()) => ExitCode::SUCCESS,
+		Err(e) => {
+			for cause in e.chain() {
+				if let Some(ioerr) = cause.downcast_ref::<std::io::Error>() {
+					if ioerr.kind() == std::io::ErrorKind::BrokenPipe {
+						return ExitCode::from(0);
+					}
+				}
+			}
+			errln!("{:#}", e).ok();
+			ExitCode::FAILURE
+		}
+	}
+}
+
+async fn run() -> anyhow::Result<()> {
 	yazi_shared::init();
 	yazi_fs::init();
 
 	if std::env::args_os().nth(1).is_some_and(|s| s == "-V" || s == "--version") {
-		println!(
+		outln!(
 			"Ya {} ({} {})",
 			env!("CARGO_PKG_VERSION"),
 			env!("VERGEN_GIT_SHA"),
 			env!("VERGEN_BUILD_DATE")
-		);
+		)?;
 		return Ok(());
 	}
 
@@ -26,7 +46,7 @@ async fn main() -> anyhow::Result<()> {
 			if let Err(e) =
 				yazi_dds::Client::shot("dds-emit", CommandPub::receiver()?, &cmd.body()?).await
 			{
-				eprintln!("Cannot emit command: {e}");
+				errln!("Cannot emit command: {e}")?;
 				std::process::exit(1);
 			}
 		}
@@ -35,24 +55,26 @@ async fn main() -> anyhow::Result<()> {
 			yazi_boot::init_default();
 			yazi_dds::init();
 			if let Err(e) = yazi_dds::Client::shot("dds-emit", cmd.receiver, &cmd.body()?).await {
-				eprintln!("Cannot emit command: {e}");
+				errln!("Cannot emit command: {e}")?;
 				std::process::exit(1);
 			}
 		}
 
 		Command::Pack(cmd) => {
 			package::init()?;
-			if cmd.install {
-				package::Package::install_from_config("plugin", false).await?;
-				package::Package::install_from_config("flavor", false).await?;
+			package::Package::load().await?.sync().await.ok();
+			if cmd.migrate {
+				outln!("Migration successful")?;
+			} else if cmd.install {
+				package::Package::load().await?.install(false).await?;
 			} else if cmd.list {
-				package::Package::list_from_config("plugin").await?;
-				package::Package::list_from_config("flavor").await?;
+				package::Package::load().await?.print()?;
 			} else if cmd.upgrade {
-				package::Package::install_from_config("plugin", true).await?;
-				package::Package::install_from_config("flavor", true).await?;
-			} else if let Some(repo) = cmd.add {
-				package::Package::add_to_config(&repo).await?;
+				package::Package::load().await?.install(true).await?;
+			} else if let Some(uses) = cmd.add {
+				package::Package::load().await?.add_many(&uses).await?;
+			} else if let Some(uses) = cmd.delete {
+				package::Package::load().await?.delete_many(&uses).await?;
 			}
 		}
 
@@ -61,7 +83,7 @@ async fn main() -> anyhow::Result<()> {
 			yazi_dds::init();
 			if let Err(e) = yazi_dds::Client::shot(&cmd.kind, CommandPub::receiver()?, &cmd.body()?).await
 			{
-				eprintln!("Cannot send message: {e}");
+				errln!("Cannot send message: {e}")?;
 				std::process::exit(1);
 			}
 		}
@@ -70,7 +92,7 @@ async fn main() -> anyhow::Result<()> {
 			yazi_boot::init_default();
 			yazi_dds::init();
 			if let Err(e) = yazi_dds::Client::shot(&cmd.kind, cmd.receiver, &cmd.body()?).await {
-				eprintln!("Cannot send message: {e}");
+				errln!("Cannot send message: {e}")?;
 				std::process::exit(1);
 			}
 		}
