@@ -1,10 +1,11 @@
 use yazi_config::popup::{Offset, Origin, Position};
-use yazi_shared::{event::Cmd, render};
+use yazi_macro::render;
+use yazi_shared::event::CmdCow;
 
 use crate::{help::Help, input::Input};
 
 impl Help {
-	pub fn filter(&mut self, _: Cmd) {
+	pub fn filter(&mut self, _: CmdCow) {
 		let mut input = Input::default();
 		input.position = Position::new(Origin::BottomLeft, Offset::line());
 
