@@ -1,21 +1,22 @@
-use yazi_shared::{event::{Cmd, Data}, fs::Url, render};
+use yazi_proxy::HIDER;
+use yazi_shared::{event::{CmdCow, Data}, url::Url};
 
 use crate::manager::Manager;
 
 #[derive(Debug, Default)]
-pub struct Opt {
+struct Opt {
 	skip:        Option<usize>,
 	force:       bool,
 	only_if:     Option<Url>,
 	upper_bound: bool,
 }
 
-impl From<Cmd> for Opt {
-	fn from(mut c: Cmd) -> Self {
+impl From<CmdCow> for Opt {
+	fn from(mut c: CmdCow) -> Self {
 		Self {
 			skip:        c.first().and_then(Data::as_usize),
 			force:       c.bool("force"),
-			only_if:     c.take("only-if").and_then(Data::into_url),
+			only_if:     c.take_url("only-if"),
 			upper_bound: c.bool("upper-bound"),
 		}
 	}
@@ -25,19 +26,26 @@ impl From<bool> for Opt {
 }
 
 impl Manager {
-	pub fn peek(&mut self, opt: impl Into<Opt>) {
+	#[yazi_codegen::command]
+	pub fn peek(&mut self, opt: Opt) {
 		let Some(hovered) = self.hovered().cloned() else {
-			return render!(self.active_mut().preview.reset());
+			return self.active_mut().preview.reset();
 		};
-
-		let folder = self.active().hovered_folder().map(|f| (f.offset, f.cha));
-		if !self.active().preview.same_url(&hovered.url) {
-			self.active_mut().preview.skip = folder.map(|f| f.0).unwrap_or_default();
-			render!(self.active_mut().preview.reset());
+		if HIDER.try_acquire().is_err() {
+			return self.active_mut().preview.reset_image();
 		}
 
-		let opt = opt.into() as Opt;
-		if matches!(opt.only_if, Some(ref u) if *u != hovered.url) {
+		let mime = self.mimetype.by_file_owned(&hovered).unwrap_or_default();
+		let folder = self.active().hovered_folder().map(|f| (f.offset, f.cha));
+
+		if !self.active().preview.same_url(&hovered.url) {
+			self.active_mut().preview.skip = folder.map(|f| f.0).unwrap_or_default();
+		}
+		if !self.active().preview.same_file(&hovered, &mime) {
+			self.active_mut().preview.reset();
+		}
+
+		if matches!(opt.only_if, Some(u) if u != hovered.url) {
 			return;
 		}
 
@@ -51,14 +59,9 @@ impl Manager {
 		}
 
 		if hovered.is_dir() {
-			self.active_mut().preview.go_folder(hovered, folder.map(|f| f.1), opt.force);
-			return;
-		}
-
-		let mime = self.mimetype.get(&hovered.url).cloned().unwrap_or_default();
-		if !mime.is_empty() {
-			// Wait till mimetype is resolved to avoid flickering
-			self.active_mut().preview.go(hovered, &mime, opt.force);
+			self.active_mut().preview.go_folder(hovered, folder.map(|(_, cha)| cha), opt.force);
+		} else {
+			self.active_mut().preview.go(hovered, mime, opt.force);
 		}
 	}
 }
