@@ -9,11 +9,8 @@ use yazi_shared::event::{CmdCow, EventQuit};
 use crate::{manager::Manager, tasks::Tasks};
 
 #[derive(Default)]
-struct Opt {
-	no_cwd_file: bool,
-}
-impl From<()> for Opt {
-	fn from(_: ()) -> Self { Self::default() }
+pub(super) struct Opt {
+	pub(super) no_cwd_file: bool,
 }
 impl From<CmdCow> for Opt {
 	fn from(c: CmdCow) -> Self { Self { no_cwd_file: c.bool("no-cwd-file") } }
@@ -40,10 +37,10 @@ impl Manager {
 			let mut rx = ConfirmProxy::show_rx(ConfirmCfg::quit(left, left_names));
 			loop {
 				select! {
-					_ = time::sleep(Duration::from_millis(100)) => {
+					_ = time::sleep(Duration::from_millis(50)) => {
 						i += 1;
-						if i > 30 { break }
-						else if ongoing.lock().len() == 0 {
+						if i > 40 { break }
+						else if ongoing.lock().is_empty() {
 							emit!(Quit(opt));
 							return;
 						}
