@@ -6,11 +6,9 @@ use parking_lot::RwLock;
 use tokio::{fs, pin, sync::{mpsc::{self, UnboundedReceiver}, watch}};
 use tokio_stream::{StreamExt, wrappers::UnboundedReceiverStream};
 use tracing::error;
-use yazi_config::PLUGIN;
 use yazi_fs::{Cha, File, Files, FilesOp, realname_unchecked};
-use yazi_plugin::isolate;
 use yazi_proxy::WATCHER;
-use yazi_shared::{RoCell, event::CmdCow, url::Url};
+use yazi_shared::{RoCell, url::Url};
 
 use super::Linked;
 use crate::tab::Folder;
@@ -44,6 +42,12 @@ impl Watcher {
 			tokio::spawn(Self::fan_in(in_rx, RecommendedWatcher::new(handler, config).unwrap()));
 		}
 
+		#[cfg(any(target_os = "linux", target_os = "macos"))]
+		yazi_fs::mounts::Partitions::monitor(
+			yazi_fs::mounts::PARTITIONS.clone(),
+			yazi_dds::Pubsub::pub_from_mount,
+		);
+
 		tokio::spawn(Self::fan_out(out_rx));
 		Self { in_tx, out_tx }
 	}
@@ -92,28 +96,17 @@ impl Watcher {
 		});
 	}
 
-	async fn fan_in(mut rx: watch::Receiver<HashSet<Url>>, mut watcher: impl notify::Watcher) {
+	async fn fan_in(
+		mut rx: watch::Receiver<HashSet<Url>>,
+		mut watcher: impl notify::Watcher + Send + 'static,
+	) {
 		loop {
-			let (mut to_unwatch, mut to_watch): (HashSet<_>, HashSet<_>) = {
+			let (to_unwatch, to_watch): (HashSet<_>, HashSet<_>) = {
 				let (new, old) = (&*rx.borrow_and_update(), &*WATCHED.read());
 				(old.difference(new).cloned().collect(), new.difference(old).cloned().collect())
 			};
 
-			to_unwatch.retain(|u| match watcher.unwatch(u) {
-				Ok(_) => true,
-				Err(e) if matches!(e.kind, notify::ErrorKind::WatchNotFound) => true,
-				Err(e) => {
-					error!("Unwatch failed: {e:?}");
-					false
-				}
-			});
-			to_watch.retain(|u| watcher.watch(u, RecursiveMode::NonRecursive).is_ok());
-
-			{
-				let mut watched = WATCHED.write();
-				watched.retain(|u| !to_unwatch.contains(u));
-				watched.extend(to_watch);
-			}
+			watcher = Self::sync_watched(watcher, to_unwatch, to_watch).await;
 
 			if !rx.has_changed().unwrap_or(false) {
 				Self::sync_linked().await;
@@ -136,7 +129,6 @@ impl Watcher {
 
 			let _permit = WATCHER.acquire().await.unwrap();
 			let mut ops = Vec::with_capacity(urls.len());
-			let mut reload = Vec::with_capacity(urls.len());
 
 			for u in urls {
 				let Some((parent, urn)) = u.pair() else { continue };
@@ -154,19 +146,40 @@ impl Watcher {
 					continue;
 				}
 
-				if !file.is_dir() {
-					reload.push(file.clone());
-				}
 				ops.push(FilesOp::Upserting(parent, HashMap::from_iter([(urn, file)])));
 			}
 
 			FilesOp::mutate(ops);
-			for (fetcher, files) in PLUGIN.mime_fetchers(reload) {
-				if let Err(e) = isolate::fetch(CmdCow::from(&fetcher.run), files).await {
-					error!("Fetch mime failed in watcher: {e}");
+		}
+	}
+
+	async fn sync_watched<W>(mut watcher: W, to_unwatch: HashSet<Url>, to_watch: HashSet<Url>) -> W
+	where
+		W: notify::Watcher + Send + 'static,
+	{
+		use notify::ErrorKind::WatchNotFound;
+
+		if to_unwatch.is_empty() && to_watch.is_empty() {
+			return watcher;
+		}
+
+		tokio::task::spawn_blocking(move || {
+			for u in to_unwatch {
+				match watcher.unwatch(&u) {
+					Ok(()) => _ = WATCHED.write().remove(&u),
+					Err(e) if matches!(e.kind, WatchNotFound) => _ = WATCHED.write().remove(&u),
+					Err(e) => error!("Unwatch failed: {e:?}"),
 				}
 			}
-		}
+			for u in to_watch {
+				if watcher.watch(&u, RecursiveMode::NonRecursive).is_ok() {
+					WATCHED.write().insert(u);
+				}
+			}
+			watcher
+		})
+		.await
+		.unwrap()
 	}
 
 	async fn sync_linked() {
