@@ -1,7 +1,7 @@
 use yazi_fs::Step;
 use yazi_macro::render;
 use yazi_proxy::ManagerProxy;
-use yazi_shared::event::{CmdCow, Data};
+use yazi_shared::event::CmdCow;
 
 use crate::tab::Tab;
 
@@ -11,13 +11,7 @@ struct Opt {
 
 impl From<CmdCow> for Opt {
 	fn from(c: CmdCow) -> Self {
-		let step = match c.first() {
-			Some(Data::Integer(i)) => Step::from(*i as isize),
-			Some(Data::String(s)) => s.parse().unwrap_or_default(),
-			_ => Step::default(),
-		};
-
-		Self { step }
+		Self { step: c.first().and_then(|d| d.try_into().ok()).unwrap_or_default() }
 	}
 }
 
@@ -28,6 +22,18 @@ impl From<isize> for Opt {
 impl Tab {
 	#[yazi_codegen::command]
 	pub fn arrow(&mut self, opt: Opt) {
+		// TODO: remove this
+		if let Step::Fixed(n) = opt.step {
+			if n <= -999 || n >= 999 {
+				yazi_proxy::AppProxy::notify_warn(
+					"Deprecated command",
+					"`arrow -99999999` and `arrow 99999999` have been deprecated, please use `arrow top` and `arrow bot` instead.
+
+See #2294 for more details: https://github.com/sxyazi/yazi/pull/2294",
+				);
+			}
+		}
+
 		if !self.current.arrow(opt.step) {
 			return;
 		}
