@@ -1,63 +1,69 @@
 use std::{mem, time::Duration};
 
 use tokio::{fs, pin};
-use tokio_stream::{wrappers::UnboundedReceiverStream, StreamExt};
+use tokio_stream::{StreamExt, wrappers::UnboundedReceiverStream};
 use yazi_config::popup::InputCfg;
 use yazi_dds::Pubsub;
+use yazi_fs::expand_path;
+use yazi_macro::render;
 use yazi_proxy::{CompletionProxy, InputProxy, ManagerProxy, TabProxy};
-use yazi_shared::{event::{Cmd, Data}, fs::{expand_path, Url}, render, Debounce, InputError};
+use yazi_shared::{Debounce, errors::InputError, event::CmdCow, url::Url};
 
 use crate::tab::Tab;
 
-pub struct Opt {
+struct Opt {
 	target:      Url,
 	interactive: bool,
 }
 
-impl From<Cmd> for Opt {
-	fn from(mut c: Cmd) -> Self {
-		let mut target = c.take_first().and_then(Data::into_url).unwrap_or_default();
-		if target.is_regular() {
-			target.set_path(expand_path(&target))
+impl From<CmdCow> for Opt {
+	fn from(mut c: CmdCow) -> Self {
+		Self {
+			interactive: c.bool("interactive"),
+			..Self::from(c.take_first_url().unwrap_or_default())
 		}
-
-		Self { target, interactive: c.bool("interactive") }
 	}
 }
+
 impl From<Url> for Opt {
-	fn from(target: Url) -> Self { Self { target, interactive: false } }
+	fn from(mut target: Url) -> Self {
+		if target.is_regular() {
+			target = Url::from(expand_path(&target));
+		}
+		Self { target, interactive: false }
+	}
 }
 
 impl Tab {
-	pub fn cd(&mut self, opt: impl Into<Opt>) {
+	#[yazi_codegen::command]
+	pub fn cd(&mut self, opt: Opt) {
 		if !self.try_escape_visual() {
 			return;
 		}
 
-		let opt = opt.into() as Opt;
 		if opt.interactive {
 			return self.cd_interactive();
 		}
 
-		if self.current.cwd == opt.target {
+		if opt.target == *self.cwd() {
 			return;
 		}
 
 		// Take parent to history
 		if let Some(rep) = self.parent.take() {
-			self.history.insert(rep.cwd.clone(), rep);
+			self.history.insert(rep.url.to_owned(), rep);
 		}
 
 		// Current
-		let rep = self.history_new(&opt.target);
+		let rep = self.history.remove_or(&opt.target);
 		let rep = mem::replace(&mut self.current, rep);
-		if rep.cwd.is_regular() {
-			self.history.insert(rep.cwd.clone(), rep);
+		if rep.url.is_regular() {
+			self.history.insert(rep.url.to_owned(), rep);
 		}
 
 		// Parent
 		if let Some(parent) = opt.target.parent_url() {
-			self.parent = Some(self.history_new(&parent));
+			self.parent = Some(self.history.remove_or(&parent));
 		}
 
 		// Backstack
@@ -65,7 +71,7 @@ impl Tab {
 			self.backstack.push(opt.target.clone());
 		}
 
-		Pubsub::pub_from_cd(self.idx, &self.current.cwd);
+		Pubsub::pub_from_cd(self.id, self.cwd());
 		ManagerProxy::refresh();
 		render!();
 	}
