@@ -1,18 +1,20 @@
-use yazi_shared::{event::Cmd, render};
+use yazi_macro::render;
+use yazi_shared::event::CmdCow;
 
 use crate::tasks::Tasks;
 
-pub struct Opt;
+struct Opt;
 
-impl From<Cmd> for Opt {
-	fn from(_: Cmd) -> Self { Self }
+impl From<CmdCow> for Opt {
+	fn from(_: CmdCow) -> Self { Self }
 }
 impl From<()> for Opt {
 	fn from(_: ()) -> Self { Self }
 }
 
 impl Tasks {
-	pub fn toggle(&mut self, _: impl Into<Opt>) {
+	#[yazi_codegen::command]
+	pub fn toggle(&mut self, _: Opt) {
 		self.visible = !self.visible;
 
 		if self.visible {
