@@ -1,10 +1,11 @@
 use std::{fmt::Display, io::Write, str::FromStr};
 
-use anyhow::{anyhow, Result};
+use anyhow::{Result, anyhow};
 use yazi_boot::BOOT;
-use yazi_shared::{emit, event::Cmd, Layer};
+use yazi_macro::emit;
+use yazi_shared::{Layer, event::Cmd};
 
-use crate::{body::Body, ID};
+use crate::{ID, body::Body};
 
 #[derive(Debug)]
 pub struct Payload<'a> {
@@ -81,6 +82,7 @@ impl Display for Payload<'_> {
 			Body::Hey(b) => serde_json::to_string(b),
 			Body::Bye(b) => serde_json::to_string(b),
 			Body::Cd(b) => serde_json::to_string(b),
+			Body::Load(b) => serde_json::to_string(b),
 			Body::Hover(b) => serde_json::to_string(b),
 			Body::Tab(b) => serde_json::to_string(b),
 			Body::Rename(b) => serde_json::to_string(b),
@@ -89,6 +91,7 @@ impl Display for Payload<'_> {
 			Body::Move(b) => serde_json::to_string(b),
 			Body::Trash(b) => serde_json::to_string(b),
 			Body::Delete(b) => serde_json::to_string(b),
+			Body::Mount(b) => serde_json::to_string(b),
 			Body::Custom(b) => serde_json::to_string(b),
 		};
 
