@@ -2,9 +2,9 @@ use std::fmt::Display;
 
 use mlua::ObjectLike;
 use scopeguard::defer;
-use tracing::warn;
+use tracing::{error, warn};
 use yazi_dds::Sendable;
-use yazi_plugin::{LUA, RtRef, loader::LOADER};
+use yazi_plugin::{LUA, RtRefMut, loader::{LOADER, Loader}};
 use yazi_proxy::{AppProxy, options::{PluginMode, PluginOpt}};
 
 use crate::{app::App, lives::Lives};
@@ -29,8 +29,9 @@ impl App {
 		}
 
 		tokio::spawn(async move {
-			if LOADER.ensure(&opt.id).await.is_ok() {
-				AppProxy::plugin_do(opt);
+			match LOADER.ensure(&opt.id).await {
+				Ok(()) => AppProxy::plugin_do(opt),
+				Err(e) => AppProxy::notify_error("Plugin load failed", e),
 			}
 		});
 	}
@@ -46,33 +47,36 @@ impl App {
 			return warn!("plugin `{}` not found", opt.id);
 		};
 
+		if let Err(e) = Loader::compatible_or_error(&opt.id, chunk) {
+			return AppProxy::notify_error("Incompatible plugin", e);
+		}
+
 		if opt.mode.auto_then(chunk.sync_entry) != PluginMode::Sync {
 			return self.cx.tasks.plugin_micro(opt);
 		}
 
-		match LUA.named_registry_value::<RtRef>("rt") {
+		match LUA.named_registry_value::<RtRefMut>("rt") {
 			Ok(mut r) => r.push(&opt.id),
 			Err(e) => return warn!("{e}"),
 		}
-		defer! { _ = LUA.named_registry_value::<RtRef>("rt").map(|mut r| r.pop()) }
+		defer! { _ = LUA.named_registry_value::<RtRefMut>("rt").map(|mut r| r.pop()) }
 
 		let plugin = match LOADER.load_with(&LUA, &opt.id, chunk) {
-			Ok(plugin) => plugin,
+			Ok(t) => t,
 			Err(e) => return warn!("{e}"),
 		};
 		drop(loader);
 
-		_ = Lives::scope(&self.cx, || {
+		let result = Lives::scope(&self.cx, || {
 			if let Some(cb) = opt.cb {
 				cb(&LUA, plugin)
 			} else {
 				let job = LUA.create_table_from([("args", Sendable::args_to_table(&LUA, opt.args)?)])?;
-
-				// TODO: remove this
-				yazi_plugin::isolate::install_entry_warn(&LUA, &job, opt._old_args).ok();
-
 				plugin.call_method("entry", job)
 			}
 		});
+		if let Err(e) = result {
+			error!("Sync plugin `{}` failed: {e}", opt.id);
+		}
 	}
 }
