@@ -1,17 +1,17 @@
-use std::{io::{stderr, BufWriter}, sync::atomic::Ordering};
+use std::{io::{BufWriter, stderr}, sync::atomic::Ordering};
 
 use crossterm::{execute, queue, terminal::{BeginSynchronizedUpdate, EndSynchronizedUpdate}};
-use ratatui::{backend::{Backend, CrosstermBackend}, buffer::Buffer, CompletedFrame};
+use ratatui::{CompletedFrame, backend::{Backend, CrosstermBackend}, buffer::Buffer};
 use scopeguard::defer;
 use yazi_plugin::elements::COLLISION;
+use yazi_shared::event::NEED_RENDER;
 
 use crate::{app::App, lives::Lives, root::Root};
 
 impl App {
 	pub(crate) fn render(&mut self) {
-		let Some(term) = &mut self.term else {
-			return;
-		};
+		NEED_RENDER.store(false, Ordering::Relaxed);
+		let Some(term) = &mut self.term else { return };
 
 		queue!(stderr(), BeginSynchronizedUpdate).ok();
 		defer! { execute!(stderr(), EndSynchronizedUpdate).ok(); }
@@ -19,7 +19,7 @@ impl App {
 		let collision = COLLISION.swap(false, Ordering::Relaxed);
 		let frame = term
 			.draw(|f| {
-				_ = Lives::scope(&self.cx, |_| Ok(f.render_widget(Root::new(&self.cx), f.area())));
+				_ = Lives::scope(&self.cx, || Ok(f.render_widget(Root::new(&self.cx), f.area())));
 
 				if let Some(pos) = self.cx.cursor() {
 					f.set_cursor_position(pos);
@@ -31,7 +31,7 @@ impl App {
 			Self::patch(frame, self.cx.cursor());
 		}
 		if !self.cx.notify.messages.is_empty() {
-			self.render_notify();
+			self.render_partially();
 		}
 
 		// Reload preview if collision is resolved
@@ -40,18 +40,19 @@ impl App {
 		}
 	}
 
-	pub(crate) fn render_notify(&mut self) {
-		let Some(term) = &mut self.term else {
-			return;
-		};
-
+	pub(crate) fn render_partially(&mut self) {
+		let Some(term) = &mut self.term else { return };
 		if !term.can_partial() {
 			return self.render();
 		}
 
 		let frame = term
 			.draw_partial(|f| {
-				f.render_widget(crate::notify::Layout::new(&self.cx), f.area());
+				_ = Lives::scope(&self.cx, || {
+					f.render_widget(crate::tasks::Progress::new(&self.cx), f.area());
+					f.render_widget(crate::notify::Notify::new(&self.cx), f.area());
+					Ok(())
+				});
 
 				if let Some(pos) = self.cx.cursor() {
 					f.set_cursor_position(pos);
