@@ -1,10 +1,11 @@
-use std::{env, fs::File};
+use std::fs::File;
 
 use anyhow::Context;
+use crossterm::style::{Color, Print, ResetColor, SetForegroundColor};
 use tracing_appender::non_blocking::WorkerGuard;
 use tracing_subscriber::EnvFilter;
 use yazi_fs::Xdg;
-use yazi_shared::RoCell;
+use yazi_shared::{LOG_LEVEL, RoCell};
 
 static _GUARD: RoCell<WorkerGuard> = RoCell::new();
 
@@ -12,9 +13,8 @@ pub(super) struct Logs;
 
 impl Logs {
 	pub(super) fn start() -> anyhow::Result<()> {
-		let mut level = env::var("YAZI_LOG").unwrap_or_default();
-		level.make_ascii_uppercase();
-		if !matches!(level.as_str(), "ERROR" | "WARN" | "INFO" | "DEBUG") {
+		let level = LOG_LEVEL.get();
+		if LOG_LEVEL.get().is_none() {
 			return Ok(());
 		}
 
@@ -29,14 +29,17 @@ impl Logs {
 		let (non_blocking, guard) = tracing_appender::non_blocking(log_file);
 		tracing_subscriber::fmt()
 			.pretty()
-			.with_env_filter(EnvFilter::new(&level))
+			.with_env_filter(EnvFilter::new(level))
 			.with_writer(non_blocking)
 			.with_ansi(cfg!(debug_assertions))
 			.init();
 
 		_GUARD.init(guard);
-		eprintln!("Running with log level `{level}`, logs are written to {log_path:?}");
-
-		Ok(())
+		Ok(crossterm::execute!(
+			std::io::stderr(),
+			SetForegroundColor(Color::Yellow),
+			Print(format!("Running with log level `{level}`, logs are written to {log_path:?}\n")),
+			ResetColor
+		)?)
 	}
 }
