@@ -1,7 +1,7 @@
 use std::{io::{self, BufWriter, Stderr, stderr}, ops::{Deref, DerefMut}, sync::atomic::{AtomicBool, AtomicU8, Ordering}};
 
 use anyhow::Result;
-use crossterm::{event::{DisableBracketedPaste, EnableBracketedPaste, KeyboardEnhancementFlags, PopKeyboardEnhancementFlags, PushKeyboardEnhancementFlags}, execute, queue, style::Print, terminal::{EnterAlternateScreen, LeaveAlternateScreen, SetTitle, disable_raw_mode, enable_raw_mode}};
+use crossterm::{event::{DisableBracketedPaste, EnableBracketedPaste, KeyboardEnhancementFlags, PopKeyboardEnhancementFlags, PushKeyboardEnhancementFlags}, execute, queue, style::Print, terminal::{LeaveAlternateScreen, SetTitle, disable_raw_mode, enable_raw_mode}};
 use cursor::RestoreCursor;
 use ratatui::{CompletedFrame, Frame, Terminal, backend::CrosstermBackend, buffer::Buffer, layout::Rect};
 use yazi_adapter::{Emulator, Mux};
@@ -26,17 +26,18 @@ impl Term {
 		};
 
 		enable_raw_mode()?;
-		if *yazi_adapter::TMUX != 0 {
+		if *yazi_adapter::TMUX {
 			yazi_adapter::Mux::tmux_passthrough();
 		}
 
 		execute!(
 			BufWriter::new(stderr()),
-			Print(Mux::csi("\x1bP$q q\x1b\\")), // Request cursor shape (DECRQM)
+			screen::SetScreen(true),
+			Print(Mux::csi("\x1bP$q q\x1b\\")), // Request cursor shape (DECRQSS query for DECSCUSR)
 			Print(Mux::csi("\x1b[?12$p")),      // Request cursor blink status (DECSET)
 			Print("\x1b[?u"),                   // Request keyboard enhancement flags (CSI u)
 			Print(Mux::csi("\x1b[0c")),         // Request device attributes
-			EnterAlternateScreen,
+			screen::SetScreen(false),
 			EnableBracketedPaste,
 			mouse::SetMouse(true),
 		)?;
@@ -159,6 +160,16 @@ impl Term {
 			queue!(stderr(), SetCursorStyle::SteadyBar)?
 		})
 	}
+
+	#[inline]
+	pub(super) fn set_cursor_underscore() -> Result<()> {
+		use crossterm::cursor::SetCursorStyle;
+		Ok(if INPUT.cursor_blink {
+			queue!(stderr(), SetCursorStyle::BlinkingUnderScore)?
+		} else {
+			queue!(stderr(), SetCursorStyle::SteadyUnderScore)?
+		})
+	}
 }
 
 impl Drop for Term {
@@ -229,7 +240,7 @@ mod cursor {
 		fn write_ansi(&self, f: &mut impl std::fmt::Write) -> std::fmt::Result {
 			let (shape, shape_blink) = match SHAPE.load(Ordering::Relaxed) {
 				u8::MAX => (0, false),
-				n => ((n.max(1) + 1) / 2, n.max(1) & 1 == 1),
+				n => (n.max(1).div_ceil(2), n.max(1) & 1 == 1),
 			};
 
 			let blink = BLINK.load(Ordering::Relaxed) ^ shape_blink;
@@ -248,3 +259,24 @@ mod cursor {
 		fn execute_winapi(&self) -> std::io::Result<()> { Ok(()) }
 	}
 }
+
+mod screen {
+	use crossterm::terminal::EnterAlternateScreen;
+	use yazi_adapter::TMUX;
+
+	pub struct SetScreen(pub bool);
+
+	impl crossterm::Command for SetScreen {
+		fn write_ansi(&self, f: &mut impl std::fmt::Write) -> std::fmt::Result {
+			if self.0 == *TMUX { Ok(()) } else { EnterAlternateScreen.write_ansi(f) }
+		}
+
+		#[cfg(windows)]
+		fn execute_winapi(&self) -> std::io::Result<()> {
+			if self.0 == *TMUX { Ok(()) } else { EnterAlternateScreen.execute_winapi() }
+		}
+
+		#[cfg(windows)]
+		fn is_ansi_code_supported(&self) -> bool { EnterAlternateScreen.is_ansi_code_supported() }
+	}
+}
