@@ -1,7 +1,7 @@
 use std::{borrow::Cow, collections::{HashMap, HashSet, VecDeque}, ffi::{OsStr, OsString}, path::{Path, PathBuf}};
 
 use anyhow::{Result, bail};
-use tokio::{fs, io, select, sync::{mpsc, oneshot}, time};
+use tokio::{fs, io::{self, AsyncWriteExt}, select, sync::{mpsc, oneshot}, time};
 
 use super::Cha;
 
@@ -22,10 +22,10 @@ pub async fn must_be_dir(p: impl AsRef<Path>) -> bool {
 }
 
 #[inline]
-pub fn ok_or_not_found(result: io::Result<()>) -> io::Result<()> {
+pub fn ok_or_not_found<T: Default>(result: io::Result<T>) -> io::Result<T> {
 	match result {
-		Ok(()) => Ok(()),
-		Err(e) if e.kind() == io::ErrorKind::NotFound => Ok(()),
+		Ok(t) => Ok(t),
+		Err(e) if e.kind() == io::ErrorKind::NotFound => Ok(T::default()),
 		Err(_) => result,
 	}
 }
@@ -83,6 +83,21 @@ async fn _paths_to_same_file(a: &Path, b: &Path) -> std::io::Result<bool> {
 	Ok(final_name(a).await? == final_name(b).await?)
 }
 
+pub async fn copy_and_seal(from: &Path, to: &Path) -> io::Result<()> {
+	let b = fs::read(from).await?;
+	ok_or_not_found(fs::remove_file(to).await)?;
+
+	let mut file =
+		fs::OpenOptions::new().create_new(true).write(true).truncate(true).open(to).await?;
+	file.write_all(&b).await?;
+
+	let mut perm = file.metadata().await?.permissions();
+	perm.set_readonly(true);
+	file.set_permissions(perm).await?;
+
+	Ok(())
+}
+
 pub async fn realname(p: &Path) -> Option<OsString> {
 	let name = p.file_name()?;
 	if p == fs::canonicalize(p).await.ok()? {
