@@ -1,7 +1,7 @@
 Entity = {
 	_inc = 1000,
 	_children = {
-		{ "space", id = 1, order = 1000 },
+		{ "spacer", id = 1, order = 1000 },
 		{ "icon", id = 2, order = 2000 },
 		{ "prefix", id = 3, order = 3000 },
 		{ "highlights", id = 4, order = 4000 },
@@ -12,7 +12,7 @@ Entity = {
 
 function Entity:new(file) return setmetatable({ _file = file }, { __index = self }) end
 
-function Entity:space() return " " end
+function Entity:spacer() return " " end
 
 function Entity:icon()
 	local icon = self._file:icon()
@@ -59,12 +59,12 @@ function Entity:found()
 	local found = self._file:found()
 	if not found then
 		return ""
+	elseif found[1] >= 99 then
+		return ""
 	end
 
-	return ui.Line {
-		"  ",
-		ui.Span(string.format("[%d/%d]", found[1] + 1, found[2])):style(THEME.manager.find_position),
-	}
+	local s = string.format("[%d/%s]", found[1] + 1, found[2] >= 100 and "99+" or found[2])
+	return ui.Line { "  ", ui.Span(s):style(THEME.manager.find_position) }
 end
 
 function Entity:symlink()
