@@ -26,6 +26,7 @@ function Root:build()
 		Header:new(self._chunks[1], cx.active),
 		Tab:new(self._chunks[2], cx.active),
 		Status:new(self._chunks[3], cx.active),
+		Modal:new(self._area),
 	}
 end
 
@@ -47,17 +48,26 @@ end
 
 -- Mouse events
 function Root:click(event, up)
-	local c = ya.child_at(ui.Rect { x = event.x, y = event.y }, self._children)
+	if tostring(cx.layer) ~= "manager" then
+		return
+	end
+	local c = ya.child_at(ui.Rect { x = event.x, y = event.y }, self:reflow())
 	return c and c:click(event, up)
 end
 
 function Root:scroll(event, step)
-	local c = ya.child_at(ui.Rect { x = event.x, y = event.y }, self._children)
+	if tostring(cx.layer) ~= "manager" then
+		return
+	end
+	local c = ya.child_at(ui.Rect { x = event.x, y = event.y }, self:reflow())
 	return c and c:scroll(event, step)
 end
 
 function Root:touch(event, step)
-	local c = ya.child_at(ui.Rect { x = event.x, y = event.y }, self._children)
+	if tostring(cx.layer) ~= "manager" then
+		return
+	end
+	local c = ya.child_at(ui.Rect { x = event.x, y = event.y }, self:reflow())
 	return c and c:touch(event, step)
 end
 
