@@ -22,9 +22,9 @@ end
 
 function Tab:build()
 	self._children = {
-		Parent:new(self._chunks[1]:padding(ui.Padding.x(1)), self._tab),
+		Parent:new(self._chunks[1]:pad(ui.Pad.x(1)), self._tab),
 		Current:new(self._chunks[2], self._tab),
-		Preview:new(self._chunks[3]:padding(ui.Padding.x(1)), self._tab),
+		Preview:new(self._chunks[3]:pad(ui.Pad.x(1)), self._tab),
 		Rail:new(self._chunks, self._tab),
 	}
 end
@@ -46,17 +46,8 @@ function Tab:redraw()
 end
 
 -- Mouse events
-function Tab:click(event, up)
-	local c = ya.child_at(ui.Rect { x = event.x, y = event.y }, self._children)
-	return c and c:click(event, up)
-end
+function Tab:click(event, up) end
 
-function Tab:scroll(event, step)
-	local c = ya.child_at(ui.Rect { x = event.x, y = event.y }, self._children)
-	return c and c:scroll(event, step)
-end
+function Tab:scroll(event, step) end
 
-function Tab:touch(event, step)
-	local c = ya.child_at(ui.Rect { x = event.x, y = event.y }, self._children)
-	return c and c:touch(event, step)
-end
+function Tab:touch(event, step) end
