@@ -6,12 +6,11 @@ function M:peek(job)
 
 	local files, bound, code = self.list_files({ "-p", tostring(job.file.url) }, job.skip, limit)
 	if code ~= 0 then
-		return ya.preview_widgets(job, {
-			ui.Text(
-				code == 2 and "File list in this archive is encrypted"
-					or "Failed to start both `7z` and `7zz`. Do you have 7-zip installed?"
-			):area(job.area),
-		})
+		return require("empty").msg(
+			job,
+			code == 2 and "File list in this archive is encrypted"
+				or "Failed to start both `7zz` and `7z`. Do you have 7-zip installed?"
+		)
 	end
 
 	for _, f in ipairs(files) do
@@ -56,15 +55,9 @@ function M.spawn_7z(args)
 		return child
 	end
 
-	local child
-	if ya.target_os() == "macos" then
-		child = try("7zz") or try("7z")
-	else
-		child = try("7z") or try("7zz")
-	end
-
+	local child = try("7zz") or try("7z")
 	if not child then
-		return ya.err("Failed to start both `7z` and `7zz`, error: " .. last_err)
+		return ya.err("Failed to start both `7zz` and `7z`, error: " .. last_err)
 	end
 	return child, last_err
 end
