@@ -1,11 +1,15 @@
 local M = {}
 
-function M:msg(job, s) ya.preview_widgets(job, { ui.Text(s):area(job.area):reverse():wrap(ui.Text.WRAP) }) end
+function M.msg(job, s)
+	ya.preview_widgets(job, {
+		ui.Text(ui.Line(s):reverse()):area(job.area):wrap(ui.Text.WRAP),
+	})
+end
 
 function M:peek(job)
 	local path = tostring(job.file.url)
 	if path:sub(1, 6) ~= "/proc/" then
-		return self:msg(job, "Empty file")
+		return self.msg(job, "Empty file")
 	end
 
 	local limit = job.area.h
@@ -22,7 +26,7 @@ function M:peek(job)
 	end)
 
 	if not ok then
-		self:msg(job, err)
+		self.msg(job, err)
 	elseif job.skip > 0 and i < job.skip + limit then
 		ya.manager_emit("peek", { math.max(0, i - limit), only_if = job.file.url, upper_bound = true })
 	else
