@@ -2,7 +2,12 @@ local M = {}
 
 function M:peek(job)
 	local start, cache = os.clock(), ya.file_cache(job)
-	if not cache or self:preload(job) ~= 1 then
+	if not cache then
+		return
+	end
+
+	local ok, err = self:preload(job)
+	if not ok or err then
 		return
 	end
 
@@ -22,10 +27,10 @@ end
 function M:preload(job)
 	local cache = ya.file_cache(job)
 	if not cache or fs.cha(cache) then
-		return 1
+		return true
 	end
 
-	local output = Command("pdftoppm")
+	local output, err = Command("pdftoppm")
 		:args({
 			"-singlefile",
 			"-jpeg",
@@ -40,16 +45,16 @@ function M:preload(job)
 		:output()
 
 	if not output then
-		return 0
+		return true, Err("Failed to start `pdftoppm`, error: %s", err)
 	elseif not output.status.success then
 		local pages = tonumber(output.stderr:match("the last page %((%d+)%)")) or 0
 		if job.skip > 0 and pages > 0 then
 			ya.manager_emit("peek", { math.max(0, pages - 1), only_if = job.file.url, upper_bound = true })
 		end
-		return 0
+		return true, Err("Failed to convert PDF to image, stderr: %s", output.stderr)
 	end
 
-	return fs.write(cache, output.stdout) and 1 or 2
+	return fs.write(cache, output.stdout)
 end
 
 return M
