@@ -1,6 +1,4 @@
-table.unpack = table.unpack or unpack
-
-ya = ya or {}
+function Err(s, ...) return Error.custom(string.format(s, ...)) end
 
 function ya.clamp(min, x, max)
 	if x < min then
@@ -31,11 +29,11 @@ end
 function ya.readable_size(size)
 	local units = { "B", "K", "M", "G", "T", "P", "E", "Z", "Y", "R", "Q" }
 	local i = 1
-	while size > 1024.0 and i < #units do
-		size = size / 1024.0
+	while size > 1024 and i < #units do
+		size = size / 1024
 		i = i + 1
 	end
-	return string.format("%.1f%s", size, units[i])
+	return string.format("%.1f%s", size, units[i]):gsub("[.,]0", "", 1)
 end
 
 function ya.readable_path(path)
@@ -49,9 +47,9 @@ function ya.readable_path(path)
 	end
 end
 
-function ya.child_at(position, children)
+function ya.child_at(pos, children)
 	for i = #children, 1, -1 do
-		if children[i]._area:contains(position) then
+		if children[i]._area:contains(pos) then
 			return children[i]
 		end
 	end
