@@ -1,13 +1,13 @@
 use globset::GlobBuilder;
-use mlua::{ExternalError, ExternalResult, Function, IntoLua, IntoLuaMulti, Lua, MetaMethod, Table, Value};
+use mlua::{ExternalError, ExternalResult, Function, IntoLua, IntoLuaMulti, Lua, Table, Value};
 use tokio::fs;
-use yazi_fs::remove_dir_clean;
+use yazi_fs::{mounts::PARTITIONS, remove_dir_clean};
 
-use crate::{Error, bindings::{Cast, Cha}, file::File, url::{Url, UrlRef}};
+use crate::{Composer, Error, bindings::Cha, file::File, url::{Url, UrlRef}};
 
-pub fn compose(lua: &Lua) -> mlua::Result<Table> {
-	let index = lua.create_function(|lua, (ts, key): (Table, mlua::String)| {
-		let value = match key.as_bytes().as_ref() {
+pub fn compose(lua: &Lua) -> mlua::Result<Value> {
+	Composer::make(lua, 10, |lua, key| {
+		match key {
 			b"cwd" => cwd(lua)?,
 			b"cha" => cha(lua)?,
 			b"write" => write(lua)?,
@@ -15,23 +15,16 @@ pub fn compose(lua: &Lua) -> mlua::Result<Table> {
 			b"remove" => remove(lua)?,
 			b"read_dir" => read_dir(lua)?,
 			b"unique_name" => unique_name(lua)?,
+			b"partitions" => partitions(lua)?,
 			_ => return Ok(Value::Nil),
 		}
-		.into_lua(lua)?;
-
-		ts.raw_set(key, value.clone())?;
-		Ok(value)
-	})?;
-
-	let fs = lua.create_table_with_capacity(0, 10)?;
-	fs.set_metatable(Some(lua.create_table_from([(MetaMethod::Index.name(), index)])?));
-
-	Ok(fs)
+		.into_lua(lua)
+	})
 }
 
 fn cwd(lua: &Lua) -> mlua::Result<Function> {
 	lua.create_function(|lua, ()| match std::env::current_dir() {
-		Ok(p) => (Url::cast(lua, p)?, Value::Nil).into_lua_multi(lua),
+		Ok(p) => (Url::from(p), Value::Nil).into_lua_multi(lua),
 		Err(e) => (Value::Nil, Error::Io(e)).into_lua_multi(lua),
 	})
 }
@@ -136,7 +129,7 @@ fn read_dir(lua: &Lua) -> mlua::Result<Function> {
 			} else {
 				yazi_fs::File::from_dummy(url, next.file_type().await.ok())
 			};
-			files.push(File::cast(&lua, file)?);
+			files.push(File(file));
 		}
 
 		let tbl = lua.create_table_with_capacity(files.len(), 0)?;
@@ -151,8 +144,26 @@ fn read_dir(lua: &Lua) -> mlua::Result<Function> {
 fn unique_name(lua: &Lua) -> mlua::Result<Function> {
 	lua.create_async_function(|lua, url: UrlRef| async move {
 		match yazi_fs::unique_name(url.clone(), async { false }).await {
-			Ok(u) => (Url::cast(&lua, u)?, Value::Nil).into_lua_multi(&lua),
+			Ok(u) => (Url(u), Value::Nil).into_lua_multi(&lua),
 			Err(e) => (Value::Nil, Error::Io(e)).into_lua_multi(&lua),
 		}
 	})
 }
+
+fn partitions(lua: &Lua) -> mlua::Result<Function> {
+	lua.create_async_function(|lua, ()| async move {
+		PARTITIONS
+			.read()
+			.iter()
+			.filter(|&p| !p.systemic())
+			.map(|p| {
+				lua.create_table_from([
+					("src", p.src.clone().into_lua(&lua)?),
+					("dist", p.dist.clone().into_lua(&lua)?),
+					("label", p.label.clone().into_lua(&lua)?),
+					("fstype", p.fstype.clone().into_lua(&lua)?),
+				])
+			})
+			.collect::<mlua::Result<Vec<Table>>>()
+	})
+}
