@@ -1,6 +1,6 @@
 use std::{collections::HashMap, ops::Deref};
 
-use anyhow::{Context, Result};
+use anyhow::{Context, Result, bail};
 use mlua::{ExternalError, Lua, Table};
 use parking_lot::RwLock;
 use tokio::fs;
@@ -51,21 +51,43 @@ impl Default for Loader {
 
 impl Loader {
 	pub async fn ensure(&self, name: &str) -> Result<()> {
-		if self.cache.read().contains_key(name) {
-			return Ok(());
+		if let Some(chunk) = self.cache.read().get(name) {
+			return Self::compatible_or_error(name, chunk);
 		}
 
-		let p = BOOT.plugin_dir.join(format!("{name}.yazi/init.lua"));
-		let chunk =
-			fs::read(&p).await.with_context(|| format!("Failed to load plugin from {p:?}"))?.into();
+		// TODO: remove this
+		let p = BOOT.plugin_dir.join(format!("{name}.yazi/main.lua"));
+		let chunk = match fs::read(&p).await {
+			Ok(b) => b,
+			Err(e) if e.kind() == std::io::ErrorKind::NotFound => {
+				static WARNED: std::sync::atomic::AtomicBool = std::sync::atomic::AtomicBool::new(false);
+				if !WARNED.swap(true, std::sync::atomic::Ordering::Relaxed) {
+					yazi_proxy::AppProxy::notify(yazi_proxy::options::NotifyOpt {
+						title:   "Deprecated entry file".to_owned(),
+						content: format!(
+							"The plugin entry file `init.lua` has been deprecated in v0.4.3 in favor of the new `main.lua`, and it will be fully removed in the next major version 0.5.
 
-		self.cache.write().insert(name.to_owned(), chunk);
-		Ok(())
+Please run `ya pack -m` to automatically migrate all plugins, or manually rename your `{name}.yazi/init.lua` to `{name}.yazi/main.lua`."
+						),
+						level:   yazi_proxy::options::NotifyLevel::Warn,
+						timeout: std::time::Duration::from_secs(25),
+					});
+				}
+
+				let p = BOOT.plugin_dir.join(format!("{name}.yazi/init.lua"));
+				fs::read(&p).await.with_context(|| format!("Failed to load plugin from {p:?}"))?
+			}
+			Err(e) => Err(e).with_context(|| format!("Failed to load plugin from {p:?}"))?,
+		};
+
+		let mut cache = self.cache.write();
+		cache.insert(name.to_owned(), chunk.into());
+		Self::compatible_or_error(name, cache.get(name).unwrap())
 	}
 
 	pub fn load(&self, lua: &Lua, id: &str) -> mlua::Result<Table> {
 		let loaded: Table = lua.globals().raw_get::<Table>("package")?.raw_get("loaded")?;
-		if let Ok(t) = loaded.raw_get::<Table>(id) {
+		if let Ok(t) = loaded.raw_get(id) {
 			return Ok(t);
 		}
 
@@ -80,13 +102,12 @@ impl Loader {
 	}
 
 	pub fn try_load(&self, lua: &Lua, id: &str) -> mlua::Result<Table> {
-		let loaded: Table = lua.globals().raw_get::<Table>("package")?.raw_get("loaded")?;
-		loaded.raw_get(id)
+		lua.globals().raw_get::<Table>("package")?.raw_get::<Table>("loaded")?.raw_get(id)
 	}
 
 	pub fn load_with(&self, lua: &Lua, id: &str, chunk: &Chunk) -> mlua::Result<Table> {
 		let loaded: Table = lua.globals().raw_get::<Table>("package")?.raw_get("loaded")?;
-		if let Ok(t) = loaded.raw_get::<Table>(id) {
+		if let Ok(t) = loaded.raw_get(id) {
 			return Ok(t);
 		}
 
@@ -96,4 +117,16 @@ impl Loader {
 		loaded.raw_set(id, t.clone())?;
 		Ok(t)
 	}
+
+	pub fn compatible_or_error(name: &str, chunk: &Chunk) -> Result<()> {
+		if chunk.compatible() {
+			return Ok(());
+		}
+
+		bail!(
+			"Plugin `{name}` requires at least Yazi {}, but your current version is Yazi {}.",
+			chunk.since,
+			yazi_boot::actions::Actions::version()
+		);
+	}
 }
