@@ -3,7 +3,7 @@ use std::sync::Arc;
 use mlua::{ExternalResult, Function, IntoLua, Lua, MetaMethod, MultiValue, ObjectLike, Table, Value};
 
 use super::LOADER;
-use crate::RtRef;
+use crate::RtRefMut;
 
 pub(super) struct Require;
 
@@ -15,9 +15,9 @@ impl Require {
 				let s = &id.to_str()?;
 				futures::executor::block_on(LOADER.ensure(s)).into_lua_err()?;
 
-				lua.named_registry_value::<RtRef>("rt")?.push(s);
+				lua.named_registry_value::<RtRefMut>("rt")?.push(s);
 				let mod_ = LOADER.load(lua, s);
-				lua.named_registry_value::<RtRef>("rt")?.pop();
+				lua.named_registry_value::<RtRefMut>("rt")?.pop();
 
 				Self::create_mt(lua, s, mod_?, true)
 			})?,
@@ -31,9 +31,9 @@ impl Require {
 				let s = &id.to_str()?;
 				LOADER.ensure(s).await.into_lua_err()?;
 
-				lua.named_registry_value::<RtRef>("rt")?.push(s);
+				lua.named_registry_value::<RtRefMut>("rt")?.push(s);
 				let mod_ = LOADER.load(&lua, s);
-				lua.named_registry_value::<RtRef>("rt")?.pop();
+				lua.named_registry_value::<RtRefMut>("rt")?.pop();
 
 				Self::create_mt(&lua, s, mod_?, false)
 			})?,
@@ -73,9 +73,9 @@ impl Require {
 		if sync {
 			lua.create_function(move |lua, args: MultiValue| {
 				let (mod_, args) = Self::split_mod_and_args(lua, &id, args)?;
-				lua.named_registry_value::<RtRef>("rt")?.push(&id);
+				lua.named_registry_value::<RtRefMut>("rt")?.push(&id);
 				let result = mod_.call_function::<MultiValue>(&f, args);
-				lua.named_registry_value::<RtRef>("rt")?.pop();
+				lua.named_registry_value::<RtRefMut>("rt")?.pop();
 				result
 			})
 		} else {
@@ -83,9 +83,9 @@ impl Require {
 				let (id, f) = (id.clone(), f.clone());
 				async move {
 					let (mod_, args) = Self::split_mod_and_args(&lua, &id, args)?;
-					lua.named_registry_value::<RtRef>("rt")?.push(&id);
+					lua.named_registry_value::<RtRefMut>("rt")?.push(&id);
 					let result = mod_.call_async_function::<MultiValue>(&f, args).await;
-					lua.named_registry_value::<RtRef>("rt")?.pop();
+					lua.named_registry_value::<RtRefMut>("rt")?.pop();
 					result
 				}
 			})
