@@ -82,13 +82,11 @@ macro_rules! impl_style_shorthands {
 macro_rules! impl_file_fields {
 	($fields:ident) => {
 		use mlua::UserDataFields;
-		use $crate::bindings::Cast;
 
 		$fields.add_field_method_get("cha", |_, me| Ok($crate::bindings::Cha::from(me.cha)));
-		$fields.add_field_method_get("url", |lua, me| $crate::url::Url::cast(lua, me.url_owned()));
-		$fields.add_field_method_get("link_to", |lua, me| {
-			me.link_to.clone().map(|u| $crate::url::Url::cast(lua, u)).transpose()
-		});
+		$fields.add_field_method_get("url", |_, me| Ok($crate::url::Url(me.url_owned())));
+		$fields
+			.add_field_method_get("link_to", |_, me| Ok(me.link_to.clone().map(|u| $crate::url::Url(u))));
 
 		$fields.add_field_method_get("name", |lua, me| {
 			Some(me.name())
@@ -104,6 +102,8 @@ macro_rules! impl_file_methods {
 	($methods:ident) => {
 		use mlua::UserDataMethods;
 
+		$methods.add_method("hash", |_, me, ()| Ok(me.hash()));
+
 		$methods.add_method("icon", |_, me, ()| {
 			use yazi_shared::theme::IconCache;
 			use $crate::bindings::Icon;
@@ -120,3 +120,14 @@ macro_rules! impl_file_methods {
 		});
 	};
 }
+
+#[macro_export]
+macro_rules! deprecate {
+	($lua:ident, $tt:tt) => {{
+		let id = match $lua.named_registry_value::<$crate::RtRef>("rt")?.current() {
+			Some(id) => &format!("`{id}.yazi` plugin"),
+			None => "`init.lua` config",
+		};
+		yazi_proxy::deprecate!(format!($tt, id));
+	}};
+}
