@@ -1,6 +1,7 @@
 use tokio::sync::oneshot;
 use yazi_config::popup::ConfirmCfg;
-use yazi_shared::{emit, event::Cmd, Layer};
+use yazi_macro::emit;
+use yazi_shared::{Layer, event::Cmd};
 
 pub struct ConfirmProxy;
 
